#ifndef BASE_VGM_VERSION_H
#define BASE_VGM_VERSION_H

// -----------------------------------------------------------------------
// The BaseVGM package of the Virtual Geometry Model
// Copyright (C) 2007 - 2022 Ivana Hrivnacova
// All rights reserved.
//
// For the licensing terms see vgm/LICENSE.
// Contact: ivana@ipno.in2p3.fr
// -----------------------------------------------------------------------

/// \ingroup BaseVGM_common
//
/// BaseVGM version
///
/// Definition of the code version and release date
///
/// \author Ivana Hrivnacova; IJClab Orsay

#define VGM_RELEASE "5.4"
#define VGM_RELEASE_DATE "18 December 2025"

#endif // BASE_VGM_VERSION_H
